@@ -192,6 +192,8 @@ func (l limaVM) Stop(ctx context.Context, force bool) error {
 		})
 	}
 
+	a.Add(func() error { l.removeHostAddresses(); return nil })
+
 	a.Add(func() error {
 		if force {
 			return l.host.Run(limactl, "stop", "--force", config.CurrentProfile().ID)
@@ -374,6 +376,16 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 		return nil
 	})
 
+	// replicate addresses when network address is disabled
+	a.Add(func() error {
+		if !conf.Network.Address {
+			if err := l.replicateHostAddresses(); err != nil {
+				logrus.Warnln(fmt.Errorf("unable to assign host IP addresses to the VM: %w", err))
+			}
+		}
+		return nil
+	})
+
 	// preserve state
 	a.Add(func() error {
 		if err := configmanager.SaveToFile(conf, config.CurrentProfile().StateFile()); err != nil {
