@@ -25,7 +25,7 @@ const LimactlCommand = "limactl"
 func Limactl(args ...string) *exec.Cmd {
 	cmd := cli.Command(LimactlCommand, args...)
 	cmd.Env = append(cmd.Env, os.Environ()...)
-	cmd.Env = append(cmd.Env, EnvLimaHome+"="+LimaHome())
+	cmd.Env = append(cmd.Env, EnvLimaHome+"="+config.LimaDir())
 	return cmd
 }
 
@@ -88,7 +88,7 @@ func (i InstanceInfo) Running() bool { return i.Status == limaStatusRunning }
 
 // Config returns the current Colima config
 func (i InstanceInfo) Config() (config.Config, error) {
-	return configmanager.LoadFrom(ColimaStateFile(i.Name))
+	return configmanager.LoadFrom(config.ProfileFromName(i.Name).StateFile())
 }
 
 // Lima statuses
@@ -108,7 +108,7 @@ func getInstance(profileID string) (InstanceInfo, error) {
 	}
 
 	if buf.Len() == 0 {
-		return i, fmt.Errorf("instance '%s' does not exist", config.Profile(profileID).DisplayName)
+		return i, fmt.Errorf("instance '%s' does not exist", config.ProfileFromName(profileID).DisplayName)
 	}
 
 	if err := json.Unmarshal(buf.Bytes(), &i); err != nil {
@@ -121,7 +121,7 @@ func getInstance(profileID string) (InstanceInfo, error) {
 func Instances(ids ...string) ([]InstanceInfo, error) {
 	limaIDs := make([]string, len(ids))
 	for i := range ids {
-		limaIDs[i] = config.Profile(ids[i]).ID
+		limaIDs[i] = config.ProfileFromName(ids[i]).ID
 	}
 	args := append([]string{"list", "--json"}, limaIDs...)
 
@@ -159,7 +159,7 @@ func Instances(ids ...string) ([]InstanceInfo, error) {
 		}
 
 		// rename to local friendly names
-		i.Name = config.Profile(i.Name).ShortName
+		i.Name = config.ProfileFromName(i.Name).ShortName
 
 		// network is low level, remove
 		i.Network = nil
@@ -185,8 +185,10 @@ func getRuntime(conf config.Config) string {
 	var runtime string
 
 	switch conf.Runtime {
-	case "docker", "containerd":
+	case "docker", "containerd", "incus":
 		runtime = conf.Runtime
+	case "none":
+		return "none"
 	default:
 		return ""
 	}
@@ -196,13 +198,3 @@ func getRuntime(conf config.Config) string {
 	}
 	return runtime
 }
-
-// LimaHome returns the config directory for Lima.
-func LimaHome() string {
-	// if LIMA_HOME env var is set, obey it.
-	if dir := os.Getenv(EnvLimaHome); dir != "" {
-		return dir
-	}
-
-	return config.LimaDir()
-}
