@@ -34,7 +34,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		l.VMType = limaconfig.VZ
 
 		// Rosetta is only available on M1
-		if conf.VZRosetta && util.MacOS13OrNewerOnM1() {
+		if conf.VZRosetta && util.MacOS13OrNewerOnArm() {
 			if util.RosettaRunning() {
 				l.Rosetta.Enabled = true
 				l.Rosetta.BinFmt = true
@@ -43,6 +43,10 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				logrus.Warnln("Run 'softwareupdate --install-rosetta' to install Rosetta2")
 			}
 		}
+
+		if util.MacOS15OrNewer() {
+			l.NestedVirtualization = conf.NestedVirtualization
+		}
 	}
 
 	if conf.CPUType != "" && conf.CPUType != "host" {
@@ -240,6 +244,21 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				Proto:          limaconfig.TCP,
 			},
 		)
+
+		// bind all host addresses when network address is not enabled
+		if !conf.Network.Address {
+			for _, ip := range util.HostIPAddresses() {
+				l.PortForwards = append(l.PortForwards,
+					limaconfig.PortForward{
+						GuestIP:        ip,
+						GuestPortRange: [2]int{1, 65535},
+						HostIP:         ip,
+						HostPortRange:  [2]int{1, 65535},
+						Proto:          limaconfig.TCP,
+					},
+				)
+			}
+		}
 	}
 
 	switch strings.ToLower(conf.MountType) {
@@ -253,25 +272,18 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		}
 	}
 
-	// Ubuntu minimal cloud image does not bundle sshfs
-	// if sshfs is used, add as a dependency
-	if l.MountType == limaconfig.REVSSHFS {
-		l.Provision = append(l.Provision, limaconfig.Provision{
-			Mode:   limaconfig.ProvisionModeDependency,
-			Script: `which sshfs || apt install -y sshfs`,
-		})
-	}
-
 	l.Provision = append(l.Provision, limaconfig.Provision{
 		Mode:   limaconfig.ProvisionModeSystem,
 		Script: "mount -a",
 	})
 
 	// trim mounted drive to recover disk space
-	l.Provision = append(l.Provision, limaconfig.Provision{
-		Mode:   limaconfig.ProvisionModeSystem,
-		Script: `readlink /usr/sbin/fstrim || fstrim -a`,
-	})
+	if conf.Runtime != incus.Name {
+		l.Provision = append(l.Provision, limaconfig.Provision{
+			Mode:   limaconfig.ProvisionModeSystem,
+			Script: `readlink /usr/sbin/fstrim || fstrim -a`,
+		})
+	}
 
 	if len(conf.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
